@@ -7,48 +7,76 @@ from prowler.config.config import (
     csv_file_suffix,
     html_file_suffix,
     json_asff_file_suffix,
-    json_file_suffix,
     json_ocsf_file_suffix,
+    orange_color,
 )
 from prowler.lib.logger import logger
-from prowler.providers.common.outputs import Provider_Output_Options
+from prowler.providers.github.models import GithubAppIdentityInfo, GithubIdentityInfo
 
 
 def display_summary_table(
     findings: list,
-    audit_info,
-    output_options: Provider_Output_Options,
-    provider: str,
+    provider,
+    output_options,
 ):
     output_directory = output_options.output_directory
     output_filename = output_options.output_filename
     try:
-        if provider == "aws":
+        if provider.type == "aws":
             entity_type = "Account"
-            audited_entities = audit_info.audited_account
-        elif provider == "azure":
+            audited_entities = provider.identity.account
+        elif provider.type == "azure":
             if (
-                audit_info.identity.domain
+                provider.identity.tenant_domain
                 != "Unknown tenant domain (missing AAD permissions)"
             ):
                 entity_type = "Tenant Domain"
-                audited_entities = audit_info.identity.domain
+                audited_entities = provider.identity.tenant_domain
             else:
                 entity_type = "Tenant ID/s"
-                audited_entities = " ".join(audit_info.identity.tenant_ids)
-        elif provider == "gcp":
+                audited_entities = " ".join(provider.identity.tenant_ids)
+        elif provider.type == "gcp":
             entity_type = "Project ID/s"
-            audited_entities = ", ".join(audit_info.project_ids)
+            audited_entities = ", ".join(provider.project_ids)
+        elif provider.type == "kubernetes":
+            entity_type = "Context"
+            audited_entities = provider.identity.context
+        elif provider.type == "github":
+            if isinstance(provider.identity, GithubIdentityInfo):
+                entity_type = "User Name"
+                audited_entities = provider.identity.account_name
+            elif isinstance(provider.identity, GithubAppIdentityInfo):
+                entity_type = "App ID"
+                audited_entities = provider.identity.app_id
+        elif provider.type == "m365":
+            entity_type = "Tenant Domain"
+            audited_entities = provider.identity.tenant_domain
+        elif provider.type == "mongodbatlas":
+            entity_type = "Organization"
+            audited_entities = provider.identity.organization_name
+        elif provider.type == "nhn":
+            entity_type = "Tenant Domain"
+            audited_entities = provider.identity.tenant_domain
+        elif provider.type == "iac":
+            if provider.scan_repository_url:
+                entity_type = "Repository"
+                audited_entities = provider.scan_repository_url
+            else:
+                entity_type = "Directory"
+                audited_entities = provider.scan_path
 
-        if findings:
+        # Check if there are findings and that they are not all MANUAL
+        if findings and not all(finding.status == "MANUAL" for finding in findings):
             current = {
                 "Service": "",
                 "Provider": "",
                 "Total": 0,
+                "Pass": 0,
                 "Critical": 0,
                 "High": 0,
                 "Medium": 0,
                 "Low": 0,
+                "Muted": 0,
             }
             findings_table = {
                 "Provider": [],
@@ -58,8 +86,11 @@ def display_summary_table(
                 "High": [],
                 "Medium": [],
                 "Low": [],
+                "Muted": [],
             }
-            pass_count = fail_count = 0
+            pass_count = fail_count = muted_count = 0
+            # Sort findings by ServiceName
+            findings.sort(key=lambda x: x.check_metadata.ServiceName)
             for finding in findings:
                 # If new service and not first, add previous row
                 if (
@@ -68,16 +99,20 @@ def display_summary_table(
                 ):
                     add_service_to_table(findings_table, current)
 
-                    current["Total"] = current["Critical"] = current["High"] = current[
-                        "Medium"
-                    ] = current["Low"] = 0
+                    current["Total"] = current["Pass"] = current["Muted"] = current[
+                        "Critical"
+                    ] = current["High"] = current["Medium"] = current["Low"] = 0
 
                 current["Service"] = finding.check_metadata.ServiceName
                 current["Provider"] = finding.check_metadata.Provider
 
                 current["Total"] += 1
+                if finding.muted:
+                    muted_count += 1
+                    current["Muted"] += 1
                 if finding.status == "PASS":
                     pass_count += 1
+                    current["Pass"] += 1
                 elif finding.status == "FAIL":
                     fail_count += 1
                     if finding.check_metadata.Severity == "critical":
@@ -98,6 +133,7 @@ def display_summary_table(
                 [
                     f"{Fore.RED}{round(fail_count / len(findings) * 100, 2)}% ({fail_count}) Failed{Style.RESET_ALL}",
                     f"{Fore.GREEN}{round(pass_count / len(findings) * 100, 2)}% ({pass_count}) Passed{Style.RESET_ALL}",
+                    f"{orange_color}{round(muted_count / len(findings) * 100, 2)}% ({muted_count}) Muted{Style.RESET_ALL}",
                 ]
             ]
             print(tabulate(overview_table, tablefmt="rounded_grid"))
@@ -107,17 +143,13 @@ def display_summary_table(
             )
             if provider == "azure":
                 print(
-                    f"\nSubscriptions scanned: {Fore.YELLOW}{' '.join(audit_info.identity.subscriptions.keys())}{Style.RESET_ALL}"
+                    f"\nSubscriptions scanned: {Fore.YELLOW}{' '.join(provider.identity.subscriptions.keys())}{Style.RESET_ALL}"
                 )
             print(tabulate(findings_table, headers="keys", tablefmt="rounded_grid"))
             print(
                 f"{Style.BRIGHT}* You only see here those services that contains resources.{Style.RESET_ALL}"
             )
             print("\nDetailed results are in:")
-            if "html" in output_options.output_modes:
-                print(
-                    f" - HTML: {output_directory}/{output_filename}{html_file_suffix}"
-                )
             if "json-asff" in output_options.output_modes:
                 print(
                     f" - JSON-ASFF: {output_directory}/{output_filename}{json_asff_file_suffix}"
@@ -128,9 +160,9 @@ def display_summary_table(
                 )
             if "csv" in output_options.output_modes:
                 print(f" - CSV: {output_directory}/{output_filename}{csv_file_suffix}")
-            if "json" in output_options.output_modes:
+            if "html" in output_options.output_modes:
                 print(
-                    f" - JSON: {output_directory}/{output_filename}{json_file_suffix}"
+                    f" - HTML: {output_directory}/{output_filename}{html_file_suffix}"
                 )
 
         else:
@@ -157,7 +189,8 @@ def add_service_to_table(findings_table, current):
         )
         current["Status"] = f"{Fore.RED}FAIL ({total_fails}){Style.RESET_ALL}"
     else:
-        current["Status"] = f"{Fore.GREEN}PASS ({current['Total']}){Style.RESET_ALL}"
+        current["Status"] = f"{Fore.GREEN}PASS ({current['Pass']}){Style.RESET_ALL}"
+
     findings_table["Provider"].append(current["Provider"])
     findings_table["Service"].append(current["Service"])
     findings_table["Status"].append(current["Status"])
@@ -169,3 +202,4 @@ def add_service_to_table(findings_table, current):
         f"{Fore.YELLOW}{current['Medium']}{Style.RESET_ALL}"
     )
     findings_table["Low"].append(f"{Fore.BLUE}{current['Low']}{Style.RESET_ALL}")
+    findings_table["Muted"].append(f"{orange_color}{current['Muted']}{Style.RESET_ALL}")
