@@ -9,11 +9,9 @@ class apigateway_restapi_logging_enabled(Check):
         findings = []
         for rest_api in apigateway_client.rest_apis:
             for stage in rest_api.stages:
-                report = Check_Report_AWS(self.metadata())
-                report.region = rest_api.region
+                report = Check_Report_AWS(metadata=self.metadata(), resource=stage)
                 report.resource_id = rest_api.name
-                report.resource_arn = stage.arn
-                report.resource_tags = stage.tags
+                report.region = rest_api.region
                 if stage.logging:
                     report.status = "PASS"
                     report.status_extended = f"API Gateway {rest_api.name} ID {rest_api.id} in stage {stage.name} has logging enabled."
