@@ -15,21 +15,25 @@ class cloudwatch_log_metric_filter_disable_or_scheduled_deletion_of_kms_cmk(Chec
     def execute(self):
         pattern = r"\$\.eventSource\s*=\s*.?kms.amazonaws.com.+\$\.eventName\s*=\s*.?DisableKey.+\$\.eventName\s*=\s*.?ScheduleKeyDeletion.?"
         findings = []
-        report = Check_Report_AWS(self.metadata())
-        report.status = "FAIL"
-        report.status_extended = (
-            "No CloudWatch log groups found with metric filters or alarms associated."
-        )
-        report.region = logs_client.region
-        report.resource_id = logs_client.audited_account
-        report.resource_arn = logs_client.log_group_arn_template
+
         report = check_cloudwatch_log_metric_filter(
             pattern,
             cloudtrail_client.trails,
             logs_client.metric_filters,
             cloudwatch_client.metric_alarms,
-            report,
+            self.metadata(),
         )
 
-        findings.append(report)
+        if cloudtrail_client.trails is not None:
+            if report is None:
+                report = Check_Report_AWS(metadata=self.metadata(), resource={})
+                report.status = "FAIL"
+                report.status_extended = "No CloudWatch log groups found with metric filters or alarms associated."
+                report.region = logs_client.region
+                report.resource_id = logs_client.audited_account
+                report.resource_arn = logs_client.log_group_arn_template
+                report.resource_tags = []
+
+            findings.append(report)
+
         return findings
