@@ -14,11 +14,8 @@ class directoryservice_ldap_certificate_expiration(Check):
         findings = []
         for directory in directoryservice_client.directories.values():
             for certificate in directory.certificates:
-                report = Check_Report_AWS(self.metadata())
-                report.region = directory.region
+                report = Check_Report_AWS(metadata=self.metadata(), resource=directory)
                 report.resource_id = certificate.id
-                report.resource_arn = directory.arn
-                report.resource_tags = directory.tags
 
                 remaining_days_to_expire = (
                     certificate.expiry_date_time
