@@ -9,15 +9,11 @@ class networkfirewall_in_all_vpc(Check):
     def execute(self):
         findings = []
         for vpc in vpc_client.vpcs.values():
-            if not vpc_client.audit_info.ignore_unused_services or vpc.in_use:
-                report = Check_Report_AWS(self.metadata())
-                report.region = vpc.region
-                report.resource_id = vpc.id
-                report.resource_arn = vpc.arn
-                report.resource_tags = vpc.tags
+            if vpc_client.provider.scan_unused_services or vpc.in_use:
+                report = Check_Report_AWS(metadata=self.metadata(), resource=vpc)
                 report.status = "FAIL"
                 report.status_extended = f"VPC {vpc.name if vpc.name else vpc.id} does not have Network Firewall enabled."
-                for firewall in networkfirewall_client.network_firewalls:
+                for firewall in networkfirewall_client.network_firewalls.values():
                     if firewall.vpc_id == vpc.id:
                         report.status = "PASS"
                         report.status_extended = f"VPC {vpc.name if vpc.name else vpc.id} has Network Firewall enabled."
