@@ -11,22 +11,25 @@ class monitor_alert_delete_sqlserver_fr(Check):
             subscription_name,
             activity_log_alerts,
         ) in monitor_client.alert_rules.items():
-            report = Check_Report_Azure(self.metadata())
-            report.status = "FAIL"
-            report.subscription = subscription_name
-            report.resource_name = "Monitor"
-            report.resource_id = "Monitor"
-            report.status_extended = f"There is not an alert for deleting SQL Server firewall rule in subscription {subscription_name}."
             for alert_rule in activity_log_alerts:
                 if check_alert_rule(
                     alert_rule, "Microsoft.Sql/servers/firewallRules/delete"
                 ):
-                    report.status = "PASS"
-                    report.resource_name = alert_rule.name
-                    report.resource_id = alert_rule.id
+                    report = Check_Report_Azure(
+                        metadata=self.metadata(), resource=alert_rule
+                    )
                     report.subscription = subscription_name
+                    report.status = "PASS"
                     report.status_extended = f"There is an alert configured for deleting SQL Server firewall rule in subscription {subscription_name}."
                     break
+            else:
+                report = Check_Report_Azure(metadata=self.metadata(), resource={})
+                report.subscription = subscription_name
+                report.resource_name = "Monitor"
+                report.resource_id = "Monitor"
+                report.status = "FAIL"
+                report.status_extended = f"There is not an alert for deleting SQL Server firewall rule in subscription {subscription_name}."
 
             findings.append(report)
+
         return findings
