@@ -8,10 +8,10 @@ class sqlserver_microsoft_defender_enabled(Check):
         for subscription, sql_servers in sqlserver_client.sql_servers.items():
             for sql_server in sql_servers:
                 if sql_server.security_alert_policies:
-                    report = Check_Report_Azure(self.metadata())
+                    report = Check_Report_Azure(
+                        metadata=self.metadata(), resource=sql_server
+                    )
                     report.subscription = subscription
-                    report.resource_name = sql_server.name
-                    report.resource_id = sql_server.id
                     report.status = "FAIL"
                     report.status_extended = f"SQL Server {sql_server.name} from subscription {subscription} has microsoft defender disabled."
                     if sql_server.security_alert_policies.state == "Enabled":
