@@ -7,12 +7,13 @@ class storage_ensure_encryption_with_customer_managed_keys(Check):
         findings = []
         for subscription, storage_accounts in storage_client.storage_accounts.items():
             for storage_account in storage_accounts:
-                report = Check_Report_Azure(self.metadata())
+                report = Check_Report_Azure(
+                    metadata=self.metadata(), resource=storage_account
+                )
                 report.subscription = subscription
                 report.status = "PASS"
                 report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} encrypts with CMKs."
-                report.resource_name = storage_account.name
-                report.resource_id = storage_account.id
+
                 if storage_account.encryption_type != "Microsoft.Keyvault":
                     report.status = "FAIL"
                     report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} does not encrypt with CMKs."
